namespace elm { namespace app { 
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type Server::icon_get() const
{
   Eina_Stringshare * __return_value =  ::elm_app_server_icon_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::icon_set( ::efl::eolian::in_traits< ::efl::eina::stringshare>::type icon) const
{
    ::elm_app_server_icon_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Stringshare *,  ::efl::eolian::in_traits< ::efl::eina::stringshare>::type>(icon));
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::server::View>>::type Server::views_get() const
{
   Eina_Iterator * __return_value =  ::elm_app_server_views_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::server::View>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Server::path_get() const
{
   const char * __return_value =  ::elm_app_server_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type Server::package_get() const
{
   Eina_Stringshare * __return_value =  ::elm_app_server_package_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::constructor( ::efl::eolian::in_traits< ::efl::eina::string_view>::type packageid,  ::efl::eolian::in_traits<Elm_App_Server_Create_View_Cb>::type create_view_cb) const
{
    ::elm_app_server_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(packageid)
      ,  ::efl::eolian::convert_to_c<Elm_App_Server_Create_View_Cb,  ::efl::eolian::in_traits<Elm_App_Server_Create_View_Cb>::type>(create_view_cb));
}
inline ::efl::eolian::return_traits<void>::type Server::close_all() const
{
    ::elm_app_server_close_all(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type Server::view_check( ::efl::eolian::in_traits< ::efl::eina::string_view>::type id) const
{
   Eina_Bool __return_value =  ::elm_app_server_view_check(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::view_add( ::efl::eolian::in_traits< ::elm::app::server::View>::type view) const
{
    ::elm_app_server_view_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_App_Server_View*,  ::efl::eolian::in_traits< ::elm::app::server::View>::type>(view));
}
inline ::efl::eolian::return_traits<void>::type Server::title_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type title) const
{
    ::elm_app_server_title_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(title));
}
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type Server::title_get() const
{
   Eina_Stringshare * __return_value =  ::elm_app_server_title_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::save() const
{
    ::elm_app_server_save(this->_eo_ptr());
}
} } 
namespace eo_cxx {
namespace elm { namespace app { 
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type Server::icon_get() const
{
   Eina_Stringshare * __return_value =  ::elm_app_server_icon_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::icon_set( ::efl::eolian::in_traits< ::efl::eina::stringshare>::type icon) const
{
    ::elm_app_server_icon_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Stringshare *,  ::efl::eolian::in_traits< ::efl::eina::stringshare>::type>(icon));
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::server::View>>::type Server::views_get() const
{
   Eina_Iterator * __return_value =  ::elm_app_server_views_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::server::View>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Server::path_get() const
{
   const char * __return_value =  ::elm_app_server_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type Server::package_get() const
{
   Eina_Stringshare * __return_value =  ::elm_app_server_package_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::constructor( ::efl::eolian::in_traits< ::efl::eina::string_view>::type packageid,  ::efl::eolian::in_traits<Elm_App_Server_Create_View_Cb>::type create_view_cb) const
{
    ::elm_app_server_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(packageid)
      ,  ::efl::eolian::convert_to_c<Elm_App_Server_Create_View_Cb,  ::efl::eolian::in_traits<Elm_App_Server_Create_View_Cb>::type>(create_view_cb));
}
inline ::efl::eolian::return_traits<void>::type Server::close_all() const
{
    ::elm_app_server_close_all(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type Server::view_check( ::efl::eolian::in_traits< ::efl::eina::string_view>::type id) const
{
   Eina_Bool __return_value =  ::elm_app_server_view_check(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::view_add( ::efl::eolian::in_traits< ::elm::app::server::View>::type view) const
{
    ::elm_app_server_view_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_App_Server_View*,  ::efl::eolian::in_traits< ::elm::app::server::View>::type>(view));
}
inline ::efl::eolian::return_traits<void>::type Server::title_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type title) const
{
    ::elm_app_server_title_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(title));
}
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type Server::title_get() const
{
   Eina_Stringshare * __return_value =  ::elm_app_server_title_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Server::save() const
{
    ::elm_app_server_save(this->_eo_ptr());
}
inline elm::app::Server::operator ::elm::app::Server() const { return *static_cast< ::elm::app::Server const*>(static_cast<void const*>(this)); }
inline elm::app::Server::operator ::elm::app::Server&() { return *static_cast< ::elm::app::Server*>(static_cast<void*>(this)); }
inline elm::app::Server::operator ::elm::app::Server const&() const { return *static_cast< ::elm::app::Server const*>(static_cast<void const*>(this)); }
} } }

